#!/bin/sh
### ====================================================================== ###
##                                                                          ##
## initPostgres.sh 
##                                                                          ##
### ====================================================================== ###


#!/bin/sh 
# PostgreSQL cluster init script for Linux

DIRNAME=`dirname $0`
. $DIRNAME/setCommonEnv.sh

DB_HOME=$(cd $DB_HOME; pwd -P)

DB_SUPERUSER=postgres
PASSWORD=$1
DATADIR=$DB_HOME/data/

#if [ -z "$DB_SUPERUSER" ]
#then
#    DB_SUPERUSER=postgres
#fi

#if [ -z "$PORT" ]
#then
#    PORT=65432
#fi

# Exit code
WARN=0

_warn() {
    echo $1
    WARN=2
}

_die() {
    echo $1
	_cleanup
    exit 1
}

_die2() {
    echo "The service user account '$1' could not be created."
    exit 1
}

_cleanup() {
	if [ -f "$PWDFILE" ];
      then
		  rm -rf "$PWDFILE"		  
    fi
	}

# Create the data directory, and set the appropriate permissions/owership
if [ ! -d "$DATADIR" ];
then
    mkdir -p "$DATADIR" || _die "Failed to create the data directory ($DATADIR)"
fi
if [ ! -d "$DB_HOME/tmp" ];
then
    mkdir -p "$DB_HOME/tmp" || _die "Failed to create the data directory ($DATADIR)"
fi
USER_ID=`id -g`
PWDFILE="$DB_HOME/tmp/.pwd"

if [ ! -z "$PASSWORD" ];
then
	echo "Authentication mode set to MD5"
	touch $PWDFILE || _die "Failed to create the initdb password file (/tmp/initdbpw.$$)"
	chmod 0600 $PWDFILE || _die "Failed to set the permissions on the initdb password file (/tmp/initdbpw.$$)"
	echo "$PASSWORD" > $PWDFILE || _die "Failed to write the initdb password file (/tmp/initdbpw.$$)"
	if [ "$USER_ID" != "0" ];
	then
		AUTHMODE="-A md5 --pwfile $PWDFILE"
	else
		AUTHMODE="-A \"md5\" --pwfile \"$PWDFILE\""
	fi
fi

# Initializing the database cluster
if [ "$USER_ID" != "0" ];
then
	LD_LIBRARY_PATH="/lib:$DB_HOME/extlib:$LD_LIBRARY_PATH"
	"$DB_HOME/bin/initdb" -U $DB_SUPERUSER -D "$DATADIR" --no-locale -E UTF8 $AUTHMODE || _die "Failed to initialise the database cluster with initdb"
else
	# Create the group if required
	if ! getent group  $DB_SUPERUSER > /dev/null
	then
   		groupadd  $DB_SUPERUSER || _die2 $DB_SUPERUSER
	fi

	# Create the user account if required
	USER_HOME_DIR=$DB_HOME
	if getent passwd  $DB_SUPERUSER > /dev/null
	then
    	HOME_DIR=`su $DB_SUPERUSER -c "echo \\\$HOME"`
    	if [ -e $HOME_DIR ]; then
        	echo "User account '$DB_SUPERUSER' already exists"
    	else
        	echo "User account '$DB_SUPERUSER' already exists - fixing non-existent home directory to $USER_HOME_DIR"
        	usermod -d "$USER_HOME_DIR"  $DB_SUPERUSER
        	exit 0
    	fi
	else
    	useradd -m -c "PostgreSQL" -d "$USER_HOME_DIR" -g  $DB_SUPERUSER  $DB_SUPERUSER || _die $DB_SUPERUSER
    	usermod -p "*"  $DB_SUPERUSER
	fi
	chown $DB_SUPERUSER:$DB_SUPERUSER "$DATADIR" || _die "Failed to set the ownership of the data directory ($DATADIR)"
	chown $DB_SUPERUSER:$DB_SUPERUSER "$DB_HOME/tmp" || _die "Failed to set the ownership of the tmp directory ($DATADIR)"
	if [ -f "$PWDFILE" ];
	then
		chown $DB_SUPERUSER:$DB_SUPERUSER $PWDFILE
	fi
    su - $DB_SUPERUSER -c "LD_LIBRARY_PATH=\"/lib:$DB_HOME/extlib:$LD_LIBRARY_PATH\" \"$DB_HOME/bin/initdb\" -U \"$DB_SUPERUSER\" -D \"$DATADIR\" --no-locale -E UTF8 $AUTHMODE" || _die "Failed to initialise the database cluster with initdb"
fi
_cleanup
echo "$0 ran to completion"
exit $WARN
